@@ -22,10 +22,9 @@ pub trait Update {
 pub trait Render {
     fn render_type(&self) -> RenderType;
     fn get_pos(&self) -> Option<&Position>;
+    fn render<'a>(&'a self, _enschin: &'a EnschinContext, _render_pass: &mut RenderPass<'a>);
     fn is_static(&self) -> bool { false }
     fn always_render(&self) -> bool { false }
-    fn render_solo<'a>(&'a self, _enschin: &'a EnschinContext, _render_pass: &mut RenderPass<'a>) {}
-    fn render_multi<'a>(&'a self, _enschin: &'a EnschinContext, _render_pass: &mut RenderPass<'a>) {}
 }
 
 pub trait Collission {
