@@ -1,6 +1,3 @@
-#![allow(dead_code)]
-
-
 #![crate_type = "lib"]
 #![crate_type = "rlib"]
 #![crate_type = "dylib"]
@@ -45,6 +42,7 @@ pub use crate::{
         render_data::RenderData,
         renderer::Renderer,
         texture::Texture,
+        sprite_sheet::SpriteSheet,
         vertex::Vertex
     },
     math::{
